==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/components/camel-splunk/src/main/java/org/apache/camel/component/splunk/support/SubmitDataWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.splunk.support;

import java.io.IOException;
import java.net.Socket;

import com.splunk.Args;
import com.splunk.Index;
import com.splunk.Receiver;
import com.splunk.Service;
import org.apache.camel.component.splunk.SplunkEndpoint;

public class SubmitDataWriter extends SplunkDataWriter {
    private String index;

    public SubmitDataWriter(SplunkEndpoint endpoint, Args args) {
        super(endpoint, args);
    }

    @Override
    protected synchronized void doWrite(String event) throws IOException {
        Index index = getIndex();
        if (index != null) {
            index.submit(args, event);
        } else {
            Receiver receiver = endpoint.getService().getReceiver();
            receiver.submit(args, event);
        }
    }

    @Override
    protected Socket createSocket(Service service) throws IOException {
        return null;
    }

    public void setIndex(String index) {
        this.index = index;
    }

    private Index getIndex() {
        return (index == null) ? null : endpoint.getService().getIndexes().get(index);
    }

}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-splunk/src/main/java/org/apache/camel/component/splunk/support/SubmitDataWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.splunk.support;

import java.io.IOException;
import java.net.Socket;

import com.splunk.Args;
import com.splunk.Index;
import com.splunk.Receiver;
import com.splunk.Service;
import org.apache.camel.component.splunk.SplunkEndpoint;

public class SubmitDataWriter extends SplunkDataWriter {
    private String index;

    public SubmitDataWriter(SplunkEndpoint endpoint, Args args) {
        super(endpoint, args);
    }

    @Override
    protected void doWrite(String event) throws IOException {
        lock.lock();
        try {
            Index index = getIndex();
            if (index != null) {
                index.submit(args, event);
            } else {
                Receiver receiver = endpoint.getService().getReceiver();
                receiver.submit(args, event);
            }
        } finally {
            lock.unlock();
        }
    }

    @Override
    protected Socket createSocket(Service service) throws IOException {
        return null;
    }

    public void setIndex(String index) {
        this.index = index;
    }

    private Index getIndex() {
        return (index == null) ? null : endpoint.getService().getIndexes().get(index);
    }

}
